@@ -2,11 +2,11 @@
 #######################################################################
 """Product class for the Zope 3 based product package
 
-$Id: rss.py 49587 2008-01-20 22:31:10Z cray $
+$Id: rss.py 49683 2008-01-23 14:24:08Z cray $
 """
 __author__  = "Elena Antusheva, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 49587 $"
+__version__ = "$Revision: 49683 $"
 
 from zope.interface import Interface
 from zope.interface import implements,implementedBy
@@ -24,6 +24,11 @@ class RSS( Persistent ) :
 
     implements(IRSS)
 
+    def __init__(self,*kv,**kw) :
+        super(RSS,self).__init__(*kv,**kw)
+        self.author = ()
+
+
     title = u""
 
     subtitle = u""
@@ -36,9 +41,9 @@ class RSS( Persistent ) :
 
     @property
     def updated(self) :
-        return IMTime(self).mtime
+        return IMTime(self).strftime()
 
-class Author( object ) :
+class Author( Persistent ) :
 
     implements(IAuthor)
 
